==> pdfadd_2.0.orig.tar.gz: pdfadd-2.0/graphedialog.h <==
/***************************************************************************
 *   copyright       : (C) 2012-2014 by Pascal Brachet                     *
 *   http://www.xm1math.net/pdfadd/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef GRAPHEDIALOG_H
#define GRAPHEDIALOG_H

#include "ui_graphedialog.h"
#include "latexhighlighter.h"
#include "pdfviewer.h"

#include <QProcess>
#include <QPointer>
#include <QCloseEvent>
#include <QProgressDialog>

class GrapheDialog : public QDialog  {
   Q_OBJECT
public:
	GrapheDialog(QWidget *parent=0);
	~GrapheDialog();
	Ui::GrapheDialog ui;
QString pdflatexCommande, asyCommande, lecteurpdfCommande, dernierRepertoire, nomFichier, preambuleAsy;
private :
QStringList sommetList, aretesList, angleList;
QList<QStringList> matrice;
QString tempDir,asyTempFile,pdfTempFile,prefixFile;
QString asyMessage;
QPointer<QProcess> asy_pdf_proc;
bool estModifie, erreurProcessus, estPondere;
LatexHighlighter *highlighterSupp;
QPointer<PdfViewer> pdfviewerWindow;
QPointer<QProgressDialog> progressDialog;
public slots:
void Ouvrir(QString nouveauFichier);
private slots:
void closeEvent(QCloseEvent *e);
void accept();
void reject();
void Init();
void ActualiserLignes(int num);
void ActualiserColonnes(int num);
void InitTableau();
void ActiverSommets(bool etat);
void GenererMatrice();
void Matrice();
void Coloration();
void PlusCourteChaine();
QString GenererCode();
void AfficherCode();
void ajouterSommet();
void supprimerSommet();
void actualiserSommet();
void actualiserAretes();
void actualiserItemInfo();
int numeroItem();
void NouveauGraphe();
void SauverGraphe();
void ChargerGraphe();

void AsyPdfTemp();
void finAsyPdfProcess(int err);
void VoirTemp();
void readInfoOutput();

void NettoyerCode();

void Aide();

void ExporterPdf();
void ExporterPdfSuite();
void CopierFichier(QString origine,QString destination);
signals:
void asy_pdf_fini();
};


#endif

==> pdfadd_2.0.1.orig.tar.gz: pdfadd-2.0.1/graphedialog.h <==
/***************************************************************************
 *   copyright       : (C) 2012-2021 by Pascal Brachet                     *
 *   https://www.xm1math.net/pdfadd/                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
 ***************************************************************************/

#ifndef GRAPHEDIALOG_H
#define GRAPHEDIALOG_H

#include "ui_graphedialog.h"
#include "latexhighlighter.h"
#include "pdfviewer.h"
#include "cmdlauncher.h"


#include <QPointer>
#include <QCloseEvent>


class GrapheDialog : public QDialog  {
   Q_OBJECT
public:
	GrapheDialog(QWidget *parent=0);
	~GrapheDialog();
	Ui::GrapheDialog ui;
QString extraPath, pdflatexCommande, asyCommande, lecteurpdfCommande, dernierRepertoire, nomFichier, preambuleAsy;
private :
QStringList sommetList, aretesList, angleList;
QList<QStringList> matrice;
QString tempDir,asyTempFile,pdfTempFile,prefixFile;
QPointer<CmdLauncher> asy_pdf_proc;
bool estModifie, erreurProcessus, estPondere;
LatexHighlighter *highlighterSupp;
QPointer<PdfViewer> pdfviewerWindow;
public slots:
void Ouvrir(QString nouveauFichier);
private slots:
void closeEvent(QCloseEvent *e);
void accept();
void reject();
void Init();
void ActualiserLignes(int num);
void ActualiserColonnes(int num);
void InitTableau();
void ActiverSommets(bool etat);
void GenererMatrice();
void Matrice();
void Coloration();
void PlusCourteChaine();
QString GenererCode();
void AfficherCode();
void ajouterSommet();
void supprimerSommet();
void actualiserSommet();
void actualiserAretes();
void actualiserItemInfo();
int numeroItem();
void NouveauGraphe();
void SauverGraphe();
void ChargerGraphe();

void AsyPdfTemp();
void VoirTemp();
void ErreurCompilation();

void NettoyerCode();

void Aide();

void ExporterPdf();
void ExporterPdfSuite();
void CopierFichier(QString origine,QString destination);
signals:
void asy_pdf_fini();
};


#endif
